@@ -6,6 +6,7 @@ from typing import List, Optional, Union
 from beartype import beartype
 
 from pglet.protocol import Command
+from pglet.ref import Ref
 
 try:
     from typing import Literal
@@ -27,6 +28,9 @@ BorderStyles = Literal[
 ]
 
 BorderStyle = Union[None, BorderStyles, List[BorderStyles]]
+BorderWidth = Union[None, str, int, float, List[str], List[int], List[float]]
+BorderColor = Union[None, str, List[str]]
+BorderRadius = Union[None, str, int, float, List[str], List[int], List[float]]
 
 TextSize = Literal[
     None,
@@ -50,6 +54,7 @@ class Control:
     def __init__(
         self,
         id=None,
+        ref: Ref = None,
         width=None,
         height=None,
         padding=None,
@@ -74,6 +79,11 @@ class Control:
         self.data = data
         self.__event_handlers = {}
         self._lock = threading.Lock()
+        if ref:
+            ref.current = self
+
+    def _assign(self, variable):
+        variable = self
 
     def _get_children(self):
         return []
@@ -103,6 +113,17 @@ class Control:
     def _set_attr(self, name, value, dirty=True):
         self._set_attr_internal(name, value, dirty)
 
+    def _get_value_or_list_attr(self, name, delimiter):
+        v = self._get_attr(name)
+        if v and delimiter in v:
+            return [x.strip() for x in v.split(delimiter)]
+        return v
+
+    def _set_value_or_list_attr(self, name, value, delimiter):
+        if isinstance(value, List):
+            value = delimiter.join([str(x) for x in value])
+        self._set_attr(name, value)
+
     def _set_attr_internal(self, name, value, dirty=True):
         name = name.lower()
         orig_val = self.__attrs.get(name)
@@ -188,7 +209,7 @@ class Control:
     # visible
     @property
     def visible(self):
-        return self._get_attr("visible")
+        return self._get_attr("visible", data_type="bool", def_value=True)
 
     @visible.setter
     @beartype
@@ -198,7 +219,7 @@ class Control:
     # disabled
     @property
     def disabled(self):
-        return self._get_attr("disabled")
+        return self._get_attr("disabled", data_type="bool", def_value=False)
 
     @disabled.setter
     @beartype
