@@ -11,6 +11,7 @@ class DatePicker(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         placeholder=None,
         required=None,
@@ -25,7 +26,9 @@ class DatePicker(Control):
         visible=None,
         disabled=None,
     ):
-        Control.__init__(self, id=id, width=width, visible=visible, disabled=disabled)
+        Control.__init__(
+            self, id=id, ref=ref, width=width, visible=visible, disabled=disabled
+        )
         self.label = label
         self.value = value
         self.placeholder = placeholder
@@ -79,7 +82,7 @@ class DatePicker(Control):
     # allow_text_input
     @property
     def allow_text_input(self):
-        return self._get_attr("allowTextInput")
+        return self._get_attr("allowTextInput", data_type="bool", def_value=False)
 
     @allow_text_input.setter
     @beartype
@@ -89,7 +92,7 @@ class DatePicker(Control):
     # underlined
     @property
     def underlined(self):
-        return self._get_attr("underlined")
+        return self._get_attr("underlined", data_type="bool", def_value=False)
 
     @underlined.setter
     @beartype
@@ -99,7 +102,7 @@ class DatePicker(Control):
     # borderless
     @property
     def borderless(self):
-        return self._get_attr("borderless")
+        return self._get_attr("borderless", data_type="bool", def_value=False)
 
     @borderless.setter
     @beartype
@@ -109,7 +112,7 @@ class DatePicker(Control):
     # required
     @property
     def required(self):
-        return self._get_attr("required")
+        return self._get_attr("required", data_type="bool", def_value=False)
 
     @required.setter
     @beartype
@@ -119,7 +122,7 @@ class DatePicker(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
