@@ -17,6 +17,7 @@ class Dialog(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         open=None,
         title=None,
         sub_text=None,
@@ -40,6 +41,7 @@ class Dialog(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -93,7 +95,7 @@ class Dialog(Control):
     # open
     @property
     def open(self):
-        return self._get_attr("open")
+        return self._get_attr("open", data_type="bool", def_value=False)
 
     @open.setter
     @beartype
@@ -150,7 +152,7 @@ class Dialog(Control):
     # fixed_top
     @property
     def fixed_top(self):
-        return self._get_attr("fixedTop")
+        return self._get_attr("fixedTop", data_type="bool", def_value=False)
 
     @fixed_top.setter
     @beartype
@@ -160,7 +162,7 @@ class Dialog(Control):
     # blocking
     @property
     def blocking(self):
-        return self._get_attr("blocking")
+        return self._get_attr("blocking", data_type="bool", def_value=False)
 
     @blocking.setter
     @beartype
@@ -177,8 +179,8 @@ class Dialog(Control):
 
 
 class Footer(Control):
-    def __init__(self, id=None, controls=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, controls=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__controls = []
         if controls != None:
