@@ -2,18 +2,19 @@ from typing import List
 
 from beartype import beartype
 
-from pglet.control import BorderStyle, Control
+from pglet.control import BorderColor, BorderRadius, BorderStyle, BorderWidth, Control
 
 
 class IFrame(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         src=None,
         border_style: BorderStyle = None,
-        border_width=None,
-        border_color=None,
-        border_radius=None,
+        border_width: BorderWidth = None,
+        border_color: BorderColor = None,
+        border_radius: BorderRadius = None,
         title=None,
         width=None,
         height=None,
@@ -26,6 +27,7 @@ class IFrame(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -56,44 +58,42 @@ class IFrame(Control):
     # border_style
     @property
     def border_style(self):
-        v = self._get_attr("borderStyle")
-        if v:
-            return [x.strip() for x in v.split(" ")]
-        return v
+        return self._get_value_or_list_attr("borderStyle", " ")
 
     @border_style.setter
     @beartype
     def border_style(self, value: BorderStyle):
-        if isinstance(value, List):
-            value = " ".join(value)
-        self._set_attr("borderStyle", value)
+        self._set_value_or_list_attr("borderStyle", value, " ")
 
     # border_width
     @property
     def border_width(self):
-        return self._get_attr("borderWidth")
+        return self._get_value_or_list_attr("borderWidth", " ")
 
     @border_width.setter
-    def border_width(self, value):
-        self._set_attr("borderWidth", value)
+    @beartype
+    def border_width(self, value: BorderWidth):
+        self._set_value_or_list_attr("borderWidth", value, " ")
 
     # border_color
     @property
     def border_color(self):
-        return self._get_attr("borderColor")
+        return self._get_value_or_list_attr("borderColor", " ")
 
     @border_color.setter
-    def border_color(self, value):
-        self._set_attr("borderColor", value)
+    @beartype
+    def border_color(self, value: BorderColor):
+        self._set_value_or_list_attr("borderColor", value, " ")
 
     # border_radius
     @property
     def border_radius(self):
-        return self._get_attr("borderRadius")
+        return self._get_value_or_list_attr("borderRadius", " ")
 
     @border_radius.setter
-    def border_radius(self, value):
-        self._set_attr("borderRadius", value)
+    @beartype
+    def border_radius(self, value: BorderRadius):
+        self._set_value_or_list_attr("borderRadius", value, " ")
 
     # title
     @property
