@@ -1,14 +1,18 @@
 from typing import Optional
-try:
-    from typing import Literal
-except:
-    from typing_extensions import Literal
 
 from beartype import beartype
 
 from pglet.control import Control
 
-MessageType = Literal[None, "info", "error", "blocked", "severeWarning", "success", "warning"]
+try:
+    from typing import Literal
+except:
+    from typing_extensions import Literal
+
+
+MessageType = Literal[
+    None, "info", "error", "blocked", "severeWarning", "success", "warning"
+]
 
 
 class Message(Control):
@@ -17,6 +21,7 @@ class Message(Control):
         value=None,
         type: MessageType = None,
         id=None,
+        ref=None,
         multiline=None,
         truncated=None,
         dismiss=None,
@@ -34,6 +39,7 @@ class Message(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -97,7 +103,7 @@ class Message(Control):
     # multiline
     @property
     def multiline(self):
-        return self._get_attr("multiline")
+        return self._get_attr("multiline", data_type="bool", def_value=False)
 
     @multiline.setter
     @beartype
@@ -107,7 +113,7 @@ class Message(Control):
     # truncated
     @property
     def truncated(self):
-        return self._get_attr("truncated")
+        return self._get_attr("truncated", data_type="bool", def_value=False)
 
     @truncated.setter
     @beartype
@@ -117,7 +123,7 @@ class Message(Control):
     # dismiss
     @property
     def dismiss(self):
-        return self._get_attr("dismiss")
+        return self._get_attr("dismiss", data_type="bool", def_value=False)
 
     @dismiss.setter
     @beartype
