@@ -1,5 +1,7 @@
 from typing import Optional, Union
+
 from beartype import beartype
+
 from pglet.control import Control
 
 
@@ -7,6 +9,7 @@ class PieChart(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         legend=None,
         tooltips=None,
         inner_value=None,
@@ -23,6 +26,7 @@ class PieChart(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -52,7 +56,7 @@ class PieChart(Control):
     # legend
     @property
     def legend(self):
-        return self._get_attr("legend")
+        return self._get_attr("legend", data_type="bool", def_value=False)
 
     @legend.setter
     @beartype
@@ -62,7 +66,7 @@ class PieChart(Control):
     # tooltips
     @property
     def tooltips(self):
-        return self._get_attr("tooltips")
+        return self._get_attr("tooltips", data_type="bool", def_value=False)
 
     @tooltips.setter
     @beartype
@@ -93,8 +97,8 @@ class PieChart(Control):
 
 
 class Data(Control):
-    def __init__(self, id=None, points=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, points=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__points = []
         if points != None:
@@ -118,8 +122,10 @@ class Data(Control):
 
 
 class Point(Control):
-    def __init__(self, id=None, value=None, legend=None, color=None, tooltip=None):
-        Control.__init__(self, id=id)
+    def __init__(
+        self, id=None, ref=None, value=None, legend=None, color=None, tooltip=None
+    ):
+        Control.__init__(self, id=id, ref=ref)
 
         self.value = value
         self.legend = legend
