@@ -1,12 +1,14 @@
 from typing import Optional, Union
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 Position = Literal[None, "left", "top", "right", "bottom"]
 
@@ -16,6 +18,7 @@ class SpinButton(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         min=None,
         max=None,
@@ -37,6 +40,7 @@ class SpinButton(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -140,7 +144,7 @@ class SpinButton(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
