@@ -1,5 +1,7 @@
 from typing import Optional
+
 from beartype import beartype
+
 from pglet.control import Control
 
 
@@ -8,6 +10,7 @@ class Tabs(Control):
         self,
         tabs=None,
         id=None,
+        ref=None,
         value=None,
         solid=None,
         on_change=None,
@@ -22,6 +25,7 @@ class Tabs(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -74,7 +78,9 @@ class Tabs(Control):
     @beartype
     def value(self, value: str):
         if not value:
-            assert not self.tabs, "Setting an empty value is only allowed if you have no tabs"
+            assert (
+                not self.tabs
+            ), "Setting an empty value is only allowed if you have no tabs"
         else:
             assert any(
                 value in keys for keys in [(tab.key, tab.text) for tab in self.tabs]
@@ -84,7 +90,7 @@ class Tabs(Control):
     # solid
     @property
     def solid(self):
-        return self._get_attr("solid")
+        return self._get_attr("solid", data_type="bool", def_value=False)
 
     @solid.setter
     @beartype
@@ -96,8 +102,10 @@ class Tabs(Control):
 
 
 class Tab(Control):
-    def __init__(self, text, controls=None, id=None, key=None, icon=None, count=None):
-        Control.__init__(self, id=id)
+    def __init__(
+        self, text, controls=None, id=None, ref=None, key=None, icon=None, count=None
+    ):
+        Control.__init__(self, id=id, ref=ref)
         assert key or text, "key or text must be specified"
         self.key = key
         self.text = text
