@@ -10,6 +10,7 @@ class Toggle(Control):
         self,
         label=None,
         id=None,
+        ref=None,
         value=None,
         value_field=None,
         inline=None,
@@ -31,6 +32,7 @@ class Toggle(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -95,7 +97,7 @@ class Toggle(Control):
     # inline
     @property
     def inline(self):
-        return self._get_attr("inline")
+        return self._get_attr("inline", data_type="bool", def_value=False)
 
     @inline.setter
     @beartype
@@ -123,7 +125,7 @@ class Toggle(Control):
     # focused
     @property
     def focused(self):
-        return self._get_attr("focused")
+        return self._get_attr("focused", data_type="bool", def_value=False)
 
     @focused.setter
     @beartype
