@@ -1,5 +1,7 @@
 from typing import Optional
+
 from beartype import beartype
+
 from pglet.control import Control
 
 
@@ -7,6 +9,7 @@ class Toolbar(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         inverted=None,
         items=None,
         overflow=None,
@@ -22,6 +25,7 @@ class Toolbar(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -44,7 +48,7 @@ class Toolbar(Control):
     # inverted
     @property
     def inverted(self):
-        return self._get_attr("inverted")
+        return self._get_attr("inverted", data_type="bool", def_value=False)
 
     @inverted.setter
     @beartype
@@ -89,8 +93,8 @@ class Toolbar(Control):
 
 
 class Overflow(Control):
-    def __init__(self, id=None, items=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, items=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__items = []
         if items != None:
@@ -114,8 +118,8 @@ class Overflow(Control):
 
 
 class Far(Control):
-    def __init__(self, id=None, items=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, items=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__items = []
         if items != None:
@@ -142,6 +146,7 @@ class Item(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         text=None,
         secondary_text=None,
         url=None,
@@ -157,7 +162,9 @@ class Item(Control):
         disabled=None,
         data=None,
     ):
-        Control.__init__(self, id=id, visible=visible, disabled=disabled, data=data)
+        Control.__init__(
+            self, id=id, ref=ref, visible=visible, disabled=disabled, data=data
+        )
 
         self.text = text
         self.secondary_text = secondary_text
@@ -225,7 +232,7 @@ class Item(Control):
     # new_window
     @property
     def new_window(self):
-        return self._get_attr("newWindow")
+        return self._get_attr("newWindow", data_type="bool", def_value=False)
 
     @new_window.setter
     @beartype
@@ -253,7 +260,7 @@ class Item(Control):
     # icon_only
     @property
     def icon_only(self):
-        return self._get_attr("iconOnly")
+        return self._get_attr("iconOnly", data_type="bool", def_value=False)
 
     @icon_only.setter
     @beartype
@@ -263,7 +270,7 @@ class Item(Control):
     # split
     @property
     def split(self):
-        return self._get_attr("split")
+        return self._get_attr("split", data_type="bool", def_value=False)
 
     @split.setter
     @beartype
@@ -273,7 +280,7 @@ class Item(Control):
     # divider
     @property
     def divider(self):
-        return self._get_attr("divider")
+        return self._get_attr("divider", data_type="bool", def_value=False)
 
     @divider.setter
     @beartype
