@@ -1,12 +1,14 @@
 from typing import Optional, Union
+
+from beartype import beartype
+
+from pglet.control import Control
+
 try:
     from typing import Literal
 except:
     from typing_extensions import Literal
 
-from beartype import beartype
-
-from pglet.control import Control
 
 XType = Literal[None, "string", "number"]
 
@@ -15,6 +17,7 @@ class VerticalBarChart(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         legend=None,
         tooltips=None,
         bar_width=None,
@@ -36,6 +39,7 @@ class VerticalBarChart(Control):
         Control.__init__(
             self,
             id=id,
+            ref=ref,
             width=width,
             height=height,
             padding=padding,
@@ -70,7 +74,7 @@ class VerticalBarChart(Control):
     # legend
     @property
     def legend(self):
-        return self._get_attr("legend")
+        return self._get_attr("legend", data_type="bool", def_value=False)
 
     @legend.setter
     @beartype
@@ -80,7 +84,7 @@ class VerticalBarChart(Control):
     # tooltips
     @property
     def tooltips(self):
-        return self._get_attr("tooltips")
+        return self._get_attr("tooltips", data_type="bool", def_value=False)
 
     @tooltips.setter
     @beartype
@@ -160,8 +164,8 @@ class VerticalBarChart(Control):
 
 
 class Data(Control):
-    def __init__(self, id=None, points=None):
-        Control.__init__(self, id=id)
+    def __init__(self, id=None, ref=None, points=None):
+        Control.__init__(self, id=id, ref=ref)
 
         self.__points = []
         if points != None:
@@ -188,6 +192,7 @@ class Point(Control):
     def __init__(
         self,
         id=None,
+        ref=None,
         x=None,
         y=None,
         legend=None,
@@ -195,7 +200,7 @@ class Point(Control):
         x_tooltip=None,
         y_tooltip=None,
     ):
-        Control.__init__(self, id=id)
+        Control.__init__(self, id=id, ref=ref)
 
         self.x = x
         self.y = y
